<?php
/*
 * Embedded video:
 * Create a RichMedia annotation which plays an embedded video
 *
 * This topic is provided only for compatibility with PDFlib 9 applications
 * (but note that you must remove the "mimetype" option to PDF_load_asset() to
 * use this code with PDFlib 9).
 *
 * It is strongly recommended to use the more powerful Screen annotations
 * and Rendition actions instead of RichMedia annotations; see PDFlib
 * Cookbook topic "screen_annotations".
 *
 * Required software: PDFlib/PDFlib+PDI/PPS 10
 * (remove the "mimetype" option in PDF_load_asset() to use with PDFlib 9)
 * Required data: video file
 */
/* This is where the data files are. Adjust as necessary */
$searchpath = dirname(__FILE__,3)."/input";
$outfile = "";
$title = "Embedded video";


/* movie file to be referenced by the link */
$videofile = "mountains.mp4";

try {
    $width = 550; $height = 310;

    $p = new pdflib();
    // Make sure we are using an appropriate PDFlib version
    if ($p->get_option("major", "") < 10) {
        print("Error: Cookbook topic '" . $title . "' requires PDFlib 10");
        die();
    }


    /* This means we must check return values of load_asset() etc. */
    $p->set_option("errorpolicy=return");

    $p->set_option("searchpath={" . $searchpath . "}");

    if ($p->begin_document($outfile, "") == 0)
        throw new Exception("Error: " . $p->get_apiname() . ": "
            . $p->get_errmsg());

    $p->set_info("Creator", "PDFlib Cookbook");
    $p->set_info("Title", $title);

    // Create template for visualizing the video before activation.
    // We display only some text; you could display an image etc.
    
    $templ = $p->begin_template_ext($width, $height, "");
    
        $p->set_graphics_option("fillcolor=red");
        $p->rect(0, 0, $width, $height);
        $p->fill();

        $p->fit_textline("Video", 10, 10,
            "fontname=NotoSerif-Regular fontsize=14 " .
            "fitmethod=meet fillcolor=black position=center boxsize={" . 
            $width . " " . $height . "}");

    $p->end_template_ext(0, 0);

    
    $p->begin_page_ext(0, 0, "width=a4.width height=a4.height");

    // Load video file as video asset for use with RichMedia annotations.
    // Remove the "mimetype" option to use this code with PDFlib 9

    $video = $p->load_asset("Video", $videofile, "mimetype=video/mp4");
    if ($video == 0)
        throw new Exception("Error: " . $p->get_errmsg());
    
    /* The option list for the RichMedia annotation specifies the
     * template as static placeholder, controls video embedding and
     * defines the the Flash helpers for playing.
     */
 
    $optlist =
    "template={normal=" . $templ . "} " .
    "richmedia={" .
        "assets={ {asset=" . $video . " name=" . $videofile . "} } " .
        "configuration={type=Video instances={ {asset=" . $videofile . "} }}" .
    "}";

    // Create the RichMedia annotation with video
    $p->create_annotation(25, 300, 575, 610, "RichMedia", $optlist);

    $p->end_page_ext("");

    $p->end_document("");

    $buf = $p->get_buffer();
    $len = strlen($buf);

    header("Content-type: application/pdf");
    header("Content-Length: $len");
    header("Content-Disposition: inline; filename=movie_annontations.pdf");
    print $buf;

} catch (PDFlibException $e) {
    echo("PDFlib exception occurred:\n".
        "[" . $e->get_errnum() . "] " . $e->get_apiname() .
        ": " . $e->get_errmsg() . "\n");
    exit(1);
} catch (Throwable $e) {
    echo("PHP exception occurred: " . $e->getMessage() . "\n");
    exit(1);
}

$p = 0;

?>
