<?php
/*
 * PDF/A-1b starter:
 * Create PDF/A-1b conforming output
 *
 * Required software: PDFlib/PDFlib+PDI/PPS 10
 * Required data: font file, image file
 */

/* This is where the data files are. Adjust as necessary. */
$searchpath = dirname(__FILE__,3)."/input";
$imagefile = "nesrin.jpg";
$outfilename = "";

try {
    $p = new PDFlib();

    // Make sure we are using an appropriate PDFlib version
    if ($p->get_option("major", "") < 10) {
        print("Error: Cookbook topic '" . $title . "' requires PDFlib 10");
        exit(1);
    }

    /* This means we must check return values of load_font() etc. */
    $p->set_option("errorpolicy=return");

    $p->set_option("searchpath={" . $searchpath . "}");

    /* PDF/A-1a requires Tagged PDF */
    if ($p->begin_document($outfilename, "pdfa=PDF/A-1b:2005") == 0) {
        echo("Error: " . $p->get_errmsg());
        exit(1);
    }

    $p->set_info("Creator", "PDFlib Cookbook");
    $p->set_info("Title", "Starter PDF/A");

    $p->begin_page_ext(0, 0, "width=a4.width height=a4.height");

    $p->fit_textline("PDF/A-1b:2005 starter", 50, 700, "fontname=NotoSerif-Regular fontsize=24");

    /* Load an RGB image */
    $image = $p->load_image("auto", $imagefile, "");

    if ($image == 0) {
        echo("Error: " . $p->get_errmsg());
        exit(1);
    }

    /* Place the $image at the bottom of the page */
    $p->fit_image($image, 0.0, 0.0, "scale=0.5");

    $p->end_page_ext("");
    $p->close_image($image);

    $p->end_document("");

    $buf = $p->get_buffer();
    $len = strlen($buf);

    header("Content-type: application/pdf");
    header("Content-Length: $len");
    header("Content-Disposition: inline; filename=starter_pdfa1b.pdf");
    print $buf;

}
catch (PDFlibException $e) {
    echo("PDFlib exception occurred in starter_pdfa1b sample:\n" .
        "[" . $e->get_errnum() . "] " . $e->get_apiname() . ": " .
        $e->get_errmsg() . "\n");
    exit(1);
}
catch (Throwable $e) {
    echo($e);
    exit(1);
}

$p = 0;
?>
