<?php
/*
 *
 * PDF/A-1b starter:
 * Create PDF/A-1b conforming output
 *
 * Required software: PDFlib/PDFlib+PDI/PPS 9
 * Required data: font file, image file
 */

/* This is where the data files are. Adjust as necessary. */
$searchpath = dirname(__FILE__,3)."/input";
$imagefile = "nesrin.jpg";
$outfilename = "";

try {
    $p = new PDFlib();


    # This means we must check return values of load_font() etc.
    $p->set_option("errorpolicy=return");

    $p->set_option("searchpath={" . $searchpath . "}");

    /* we use "utf8" as stringformat */
    $p->set_option("stringformat=utf8");

    /* PDF/A-1a requires Tagged PDF */
    if ($p->begin_document($outfilename, "pdfa=PDF/A-1b:2005") == 0) {
        echo("Error: " . $p->get_errmsg());
        exit(1);
    }

    /*
     * We use sRGB as output intent since it allows the color
     * spaces CIELab, ICC-based, grayscale, and RGB.
     *
     * If you need CMYK color you must use a CMYK output profile.
     */

    if( $p->load_iccprofile("sRGB", "usage=outputintent") == 0)
    {
        throw new Exception("Error: " . p.get_errmsg() ."<br/>\n" . 
            "See www.pdflib.com for output intent ICC profiles.");
    }

    $p->set_info("Creator", "PDFlib Cookbook");
    $p->set_info("Title", "Starter PDF/A");

    $p->begin_page_ext(0, 0, "width=a4.width height=a4.height");

    /* $font embedding is required for PDF/A */
    $font = $p->load_font("NotoSerif-Regular", "unicode", "embedding");
    if ($font == 0) {
        echo("Error: " . $p->get_errmsg());
        exit(1);
    }
    $p->setfont($font, 24);

    $p->fit_textline("PDF/A-1b:2005 starter", 50, 700, "");

    /* We can use an RGB $image since we already supplied an
     * output intent profile.
     */
    $image = $p->load_image("auto", $imagefile, "");

    if ($image == 0) {
        echo("Error: " . $p->get_errmsg());
        exit(1);
    }

    /* Place the $image at the bottom of the page */
    $p->fit_image($image, 0.0, 0.0, "scale=0.5");

    $p->end_page_ext("");
    $p->close_image($image);

    $p->end_document("");

    $buf = $p->get_buffer();
    $len = strlen($buf);

    header("Content-type: application/pdf");
    header("Content-Length: $len");
    header("Content-Disposition: inline; filename=starter_pdfa1b_9.pdf");
    print $buf;

}
catch (PDFlibException $e) {
    echo("PDFlib exception occurred in starter_pdfa1b sample:\n" .
        "[" . $e->get_errnum() . "] " . $e->get_apiname() . ": " .
        $e->get_errmsg() . "\n");
    exit(1);
}
catch (Throwable $e) {
    echo($e);
    exit(1);
}

$p = 0;
?>
